package cn.estsh.i3plus.ext.mes.pcn.apiservice.serviceimpl.ford;

import cn.estsh.i3plus.ext.mes.pcn.api.busi.ford.IFordFetchWebService;
import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.ford.MesFordFetchParameter;
import cn.estsh.i3plus.pojo.mes.repository.ford.MesFordFetchParameterRepository;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.net.HttpCookie;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Optional;

@Service
@Slf4j
public class MesFordFetchWebServiceImpl implements IFordFetchWebService {
    @Autowired
    private MesFordFetchParameterRepository paramRao;

    @Override
    public void insertParams(MesFordFetchParameter parameter) {
       ConvertBean.saveOrUpdate(parameter, parameter.getCreateUser());
        paramRao.insert(parameter);

    }

    @Override
    public void updateParams(MesFordFetchParameter parameter) {
        ConvertBean.saveOrUpdate(parameter, parameter.getCreateUser());
        paramRao.update(parameter);
    }

    @Override
    public void deleteParams(Long id,String userName) {
        paramRao.deleteWeaklyById(id,userName);
    }

    @Override
    public MesFordFetchParameter queryParams(Long id) {
        Optional<MesFordFetchParameter> params = paramRao.findById(id);
        return params.orElseGet(MesFordFetchParameter::new);

    }

    @Override
    public List<MesFordFetchParameter> queryParams(String organizeCode) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        return paramRao.findByHqlWhere(ddlPackBean);
    }

    @Override
    public void doFetchData(Long id, String organizeCode) {
        DdlPackBean ddlPackBean = DdlPackBean.getDdlPackBean(organizeCode);
        DdlPreparedPack.getNumEqualPack(id,"id",ddlPackBean);
        List<MesFordFetchParameter> list = paramRao.findByHqlWhere(ddlPackBean);
        if (list.isEmpty()) {
            throw ImppExceptionBuilder.newInstance().setErrorDetail("未查询出当前配置,请检查数据!").build();
        }
        MesFordFetchParameter parameter = list.get(0);
        //尝试登录
        Map<String, Object> paramMap = new HashMap<>();
        paramMap.put("username", parameter.getUid());
        paramMap.put("passwork", parameter.getPwd());
        Map<String,Object> header = new HashMap<>();
        header.put("content-type","application/x-www-form-urlencoded");
        HttpResponse loginResponse = HttpRequest.post(parameter.getLoginUrl()).form(paramMap).execute();
        if (loginResponse.getStatus() != 200){
            log.info("登录失败,需要重新登录!返回内容为:{}",loginResponse.body());
        }
        List<HttpCookie> cookies = loginResponse.getCookies();
        //拼接请求参数
        //time=0.9656002469020775&maxpage=5&trigger=B100VR12&st=2023-05-12%2005:00:00&et=2023-05-12%2023:59:59&catacode=0&itemcode=0
        Map<String,Object> map = new HashMap<>();
        map.put("maxpage",parameter.getPageSize() != null ? parameter.getPageSize().toString() : "1");
        map.put("trigger",parameter.getInfoPointCode());
        map.put("st",parameter.getStartDateTime());
        map.put("et",parameter.getEndDateTime());
        map.put("catacode","0");
        map.put("itemcode","0");
        HttpResponse response = HttpRequest.get(parameter.getFetchUrl()).cookie(cookies).timeout(60000).form(map).execute();
        log.info("查询出来的内容为:{}",response.body());
    }
}
